@@ -18,7 +18,7 @@ use constant VALIDATE_IP       => eval 'require Data::Validate::IP;1';
 
 use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || 0;
 
-our $VERSION = '0.91';
+our $VERSION = '0.92';
 our @EXPORT_OK = 'validate_json';
 
 my $HTTP_SCHEME_RE = qr{^https?:};
@@ -244,7 +244,7 @@ sub _resolve_schema {
 
         # int($v) returns the memory address of the reference. The "if" below
         # will not resolve the same "$ref" over again.
-        next if $k eq '$ref' and ref $v and $self->{seen}{int($v)}++;
+        next if ref $v and $self->{seen}{int($v)}++;
 
         # Make sure we do not modify the input data structure.
         # Changing the input makes t/expand.t in swagger2.git fail.
@@ -785,7 +785,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.91
+0.92
 
 =head1 SYNOPSIS
 
